GattSubscription class
Whether a central is subscribed to one characteristic.
Constructors
- GattSubscription({required String characteristicUuid, required bool subscribed})
-
Creates a subscription report.
const
Properties
- characteristicUuid → String
-
The uuid of the characteristic, in the full 128 bit form, whichever form
it was configured with.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscribed → bool
-
Whether at least one central is subscribed to it.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited